@@ -174,12 +174,10 @@ class TextGenerator(ABC):
 		super().__init__()
 
 	@abstractmethod
-	def generate(self) -> str:
-		pass
+	def generate(self) -> str: ...
 
 	@abstractmethod
-	def set_length(self):
-		pass
+	def set_length(self): ...
 
 
 class Nick(Sounds, TextGenerator):
